@@ -1,6 +1,6 @@
 /* ncdc - NCurses Direct Connect client
 
-  Copyright (c) 2011-2019 Yoran Heling
+  Copyright (c) 2011-2022 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -386,7 +386,7 @@ static char *i_cid_pid() {
 
   // Generate a random PID
   char pid[24];
-  crypt_rnd(pid, 24);
+  g_warn_if_fail(gnutls_rnd(GNUTLS_RND_RANDOM, pid, 24) == 0);
 
   // now hash the PID so we have our CID
   char cid[24];
@@ -742,12 +742,14 @@ static char *p_sendfile(const char *val, GError **err) {
 #define VAR_TLSP_DISABLE 1
 #define VAR_TLSP_ALLOW   2
 #define VAR_TLSP_PREFER  4
+#define VAR_TLSP_FORCE   8
 #endif
 
 static flag_option_t var_tls_policy_ops[] = {
   { VAR_TLSP_DISABLE, "disabled" },
   { VAR_TLSP_ALLOW,   "allow"    },
   { VAR_TLSP_PREFER,  "prefer"   },
+  { VAR_TLSP_FORCE,   "force"    },
   { 0 }
 };
 
